@@ -1,7 +1,7 @@
-function _aws_cdk_aws_resiliencehub_CfnAppProps(p) {
-}
 function _aws_cdk_aws_resiliencehub_CfnResiliencyPolicyProps(p) {
 }
+function _aws_cdk_aws_resiliencehub_CfnAppProps(p) {
+}
 function _aws_cdk_aws_resiliencehub_CfnApp(p) {
 }
 function _aws_cdk_aws_resiliencehub_CfnApp_PhysicalResourceIdProperty(p) {
@@ -27,5 +27,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_resiliencehub_CfnAppProps, _aws_cdk_aws_resiliencehub_CfnResiliencyPolicyProps, _aws_cdk_aws_resiliencehub_CfnApp, _aws_cdk_aws_resiliencehub_CfnApp_PhysicalResourceIdProperty, _aws_cdk_aws_resiliencehub_CfnResiliencyPolicy, _aws_cdk_aws_resiliencehub_CfnResiliencyPolicy_FailurePolicyProperty, _aws_cdk_aws_resiliencehub_CfnApp_ResourceMappingProperty };
+module.exports = { print, _aws_cdk_aws_resiliencehub_CfnResiliencyPolicyProps, _aws_cdk_aws_resiliencehub_CfnAppProps, _aws_cdk_aws_resiliencehub_CfnApp, _aws_cdk_aws_resiliencehub_CfnApp_PhysicalResourceIdProperty, _aws_cdk_aws_resiliencehub_CfnResiliencyPolicy, _aws_cdk_aws_resiliencehub_CfnResiliencyPolicy_FailurePolicyProperty, _aws_cdk_aws_resiliencehub_CfnApp_ResourceMappingProperty };
 module.exports.DeprecationError = DeprecationError;
